==> polished-1.9.2.jar: META-INF/resources/webjars/polished/1.9.2/lib/index.d.ts <==
import adjustHue from './color/adjustHue';
import animation from './shorthands/animation';
import backgroundImages from './shorthands/backgroundImages';
import backgrounds from './shorthands/backgrounds';
import borderColor from './shorthands/borderColor';
import borderRadius from './shorthands/borderRadius';
import borderStyle from './shorthands/borderStyle';
import borderWidth from './shorthands/borderWidth';
import buttons from './shorthands/buttons';
import clearFix from './mixins/clearFix';
import complement from './color/complement';
import darken from './color/darken';
import desaturate from './color/desaturate';
import directionalProperty from './helpers/directionalProperty';
import ellipsis from './mixins/ellipsis';
import em from './helpers/em';
import fontFace from './mixins/fontFace';
import getLuminance from './color/getLuminance';
import grayscale from './color/grayscale';
import invert from './color/invert';
import hideText from './mixins/hideText';
import hideVisually from './mixins/hideVisually';
import hiDPI from './mixins/hiDPI';
import hsl from './color/hsl';
import hsla from './color/hsla';
import lighten from './color/lighten';
import margin from './shorthands/margin';
import mix from './color/mix';
import modularScale from './helpers/modularScale';
import normalize from './mixins/normalize';
import opacify from './color/opacify';
import padding from './shorthands/padding';
import parseToHsl from './color/parseToHsl';
import parseToRgb from './color/parseToRgb';
import placeholder from './mixins/placeholder';
import position from './shorthands/position';
import radialGradient from './mixins/radialGradient';
import readableColor from './color/readableColor';
import rem from './helpers/rem';
import retinaImage from './mixins/retinaImage';
import rgb from './color/rgb';
import rgba from './color/rgba';
import saturate from './color/saturate';
import selection from './mixins/selection';
import setHue from './color/setHue';
import setLightness from './color/setLightness';
import setSaturation from './color/setSaturation';
import shade from './color/shade';
import size from './shorthands/size';
import stripUnit from './helpers/stripUnit';
import textInputs from './shorthands/textInputs';
import timingFunctions from './mixins/timingFunctions';
import tint from './color/tint';
import toColorString from './color/toColorString';
import transitions from './shorthands/transitions';
import transparentize from './color/transparentize';
import triangle from './mixins/triangle';
import wordWrap from './mixins/wordWrap';

export { adjustHue };
export { animation };
export { backgroundImages };
export { backgrounds };
export { borderColor };
export { borderRadius };
export { borderStyle };
export { borderWidth };
export { buttons };
export { clearFix };
export { complement };
export { darken };
export { desaturate };
export { directionalProperty };
export { ellipsis };
export { em };
export { fontFace };
export { getLuminance };
export { grayscale };
export { invert };
export { hideText };
export { hideVisually };
export { hiDPI };
export { hsl };
export { hsla };
export { lighten };
export { margin };
export { mix };
export { modularScale };
export { normalize };
export { opacify };
export { padding };
export { parseToHsl };
export { parseToRgb };
export { placeholder };
export { position };
export { radialGradient };
export { readableColor };
export { rem };
export { retinaImage };
export { rgb };
export { rgba };
export { saturate };
export { selection };
export { setHue };
export { setLightness };
export { setSaturation };
export { shade };
export { size };
export { stripUnit };
export { textInputs };
export { timingFunctions };
export { tint };
export { toColorString };
export { transitions };
export { transparentize };
export { triangle };
export { wordWrap };

==> polished-2.3.3.jar: META-INF/resources/webjars/polished/2.3.3/lib/index.d.ts <==
import adjustHue from './color/adjustHue';
import animation from './shorthands/animation';
import backgroundImages from './shorthands/backgroundImages';
import backgrounds from './shorthands/backgrounds';
import between from './mixins/between';
import border from './shorthands/border';
import borderColor from './shorthands/borderColor';
import borderRadius from './shorthands/borderRadius';
import borderStyle from './shorthands/borderStyle';
import borderWidth from './shorthands/borderWidth';
import buttons from './shorthands/buttons';
import clearFix from './mixins/clearFix';
import complement from './color/complement';
import cover from './mixins/cover';
import darken from './color/darken';
import desaturate from './color/desaturate';
import directionalProperty from './helpers/directionalProperty';
import ellipsis from './mixins/ellipsis';
import em from './helpers/em';
import fluidRange from './mixins/fluidRange';
import fontFace from './mixins/fontFace';
import getLuminance from './color/getLuminance';
import getValueAndUnit from './helpers/getValueAndUnit';
import grayscale from './color/grayscale';
import invert from './color/invert';
import hideText from './mixins/hideText';
import hideVisually from './mixins/hideVisually';
import hiDPI from './mixins/hiDPI';
import hsl from './color/hsl';
import hsla from './color/hsla';
import lighten from './color/lighten';
import margin from './shorthands/margin';
import mix from './color/mix';
import modularScale from './helpers/modularScale';
import normalize from './mixins/normalize';
import opacify from './color/opacify';
import padding from './shorthands/padding';
import parseToHsl from './color/parseToHsl';
import parseToRgb from './color/parseToRgb';
import placeholder from './mixins/placeholder';
import position from './shorthands/position';
import radialGradient from './mixins/radialGradient';
import readableColor from './color/readableColor';
import rem from './helpers/rem';
import retinaImage from './mixins/retinaImage';
import rgb from './color/rgb';
import rgba from './color/rgba';
import saturate from './color/saturate';
import selection from './mixins/selection';
import setHue from './color/setHue';
import setLightness from './color/setLightness';
import setSaturation from './color/setSaturation';
import shade from './color/shade';
import size from './shorthands/size';
import stripUnit from './helpers/stripUnit';
import textInputs from './shorthands/textInputs';
import timingFunctions from './mixins/timingFunctions';
import tint from './color/tint';
import toColorString from './color/toColorString';
import transitions from './shorthands/transitions';
import transparentize from './color/transparentize';
import triangle from './mixins/triangle';
import wordWrap from './mixins/wordWrap';

export { adjustHue };
export { animation };
export { backgroundImages };
export { backgrounds };
export { between };
export { border };
export { borderColor };
export { borderRadius };
export { borderStyle };
export { borderWidth };
export { buttons };
export { clearFix };
export { complement };
export { cover };
export { darken };
export { desaturate };
export { directionalProperty };
export { ellipsis };
export { em };
export { fluidRange };
export { fontFace };
export { getLuminance };
export { getValueAndUnit };
export { grayscale };
export { invert };
export { hideText };
export { hideVisually };
export { hiDPI };
export { hsl };
export { hsla };
export { lighten };
export { margin };
export { mix };
export { modularScale };
export { normalize };
export { opacify };
export { padding };
export { parseToHsl };
export { parseToRgb };
export { placeholder };
export { position };
export { radialGradient };
export { readableColor };
export { rem };
export { retinaImage };
export { rgb };
export { rgba };
export { saturate };
export { selection };
export { setHue };
export { setLightness };
export { setSaturation };
export { shade };
export { size };
export { stripUnit };
export { textInputs };
export { timingFunctions };
export { tint };
export { toColorString };
export { transitions };
export { transparentize };
export { triangle };
export { wordWrap };
